package com.yanzhu.manage.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.manage.mapper.BusExamUserResultMapper;
import com.yanzhu.manage.domain.BusExamUserResult;
import com.yanzhu.manage.service.IBusExamUserResultService;

/**
 * 用户试卷结果Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
@Service
public class BusExamUserResultServiceImpl implements IBusExamUserResultService 
{
    @Autowired
    private BusExamUserResultMapper busExamUserResultMapper;

    /**
     * 查询用户试卷结果
     * 
     * @param examUserId 用户试卷结果主键
     * @return 用户试卷结果
     */
    @Override
    public BusExamUserResult selectBusExamUserResultByExamUserId(Long examUserId)
    {
        return busExamUserResultMapper.selectBusExamUserResultByExamUserId(examUserId);
    }

    /**
     * 查询用户试卷结果列表
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 用户试卷结果
     */
    @Override
    public List<BusExamUserResult> selectBusExamUserResultList(BusExamUserResult busExamUserResult)
    {
        return busExamUserResultMapper.selectBusExamUserResultList(busExamUserResult);
    }

    /**
     * 新增用户试卷结果
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 结果
     */
    @Override
    public int insertBusExamUserResult(BusExamUserResult busExamUserResult)
    {
        return busExamUserResultMapper.insertBusExamUserResult(busExamUserResult);
    }

    /**
     * 修改用户试卷结果
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 结果
     */
    @Override
    public int updateBusExamUserResult(BusExamUserResult busExamUserResult)
    {
        return busExamUserResultMapper.updateBusExamUserResult(busExamUserResult);
    }

    /**
     * 批量删除用户试卷结果
     * 
     * @param examUserIds 需要删除的用户试卷结果主键
     * @return 结果
     */
    @Override
    public int deleteBusExamUserResultByExamUserIds(Long[] examUserIds)
    {
        return busExamUserResultMapper.deleteBusExamUserResultByExamUserIds(examUserIds);
    }

    /**
     * 删除用户试卷结果信息
     * 
     * @param examUserId 用户试卷结果主键
     * @return 结果
     */
    @Override
    public int deleteBusExamUserResultByExamUserId(Long examUserId)
    {
        return busExamUserResultMapper.deleteBusExamUserResultByExamUserId(examUserId);
    }
}
