package com.yanzhu.manage.service.impl;

import java.util.List;
import com.yanzhu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.manage.mapper.BusExamUserMapper;
import com.yanzhu.manage.domain.BusExamUser;
import com.yanzhu.manage.service.IBusExamUserService;

/**
 * 用户试卷Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
@Service
public class BusExamUserServiceImpl implements IBusExamUserService 
{
    @Autowired
    private BusExamUserMapper busExamUserMapper;

    /**
     * 查询用户试卷
     * 
     * @param id 用户试卷主键
     * @return 用户试卷
     */
    @Override
    public BusExamUser selectBusExamUserById(Long id)
    {
        return busExamUserMapper.selectBusExamUserById(id);
    }

    /**
     * 查询用户试卷列表
     * 
     * @param busExamUser 用户试卷
     * @return 用户试卷
     */
    @Override
    public List<BusExamUser> selectBusExamUserList(BusExamUser busExamUser)
    {
        return busExamUserMapper.selectBusExamUserList(busExamUser);
    }

    /**
     * 新增用户试卷
     * 
     * @param busExamUser 用户试卷
     * @return 结果
     */
    @Override
    public int insertBusExamUser(BusExamUser busExamUser)
    {
        busExamUser.setCreateTime(DateUtils.getNowDate());
        return busExamUserMapper.insertBusExamUser(busExamUser);
    }

    /**
     * 修改用户试卷
     * 
     * @param busExamUser 用户试卷
     * @return 结果
     */
    @Override
    public int updateBusExamUser(BusExamUser busExamUser)
    {
        busExamUser.setUpdateTime(DateUtils.getNowDate());
        return busExamUserMapper.updateBusExamUser(busExamUser);
    }

    /**
     * 批量删除用户试卷
     * 
     * @param ids 需要删除的用户试卷主键
     * @return 结果
     */
    @Override
    public int deleteBusExamUserByIds(Long[] ids)
    {
        return busExamUserMapper.deleteBusExamUserByIds(ids);
    }

    /**
     * 删除用户试卷信息
     * 
     * @param id 用户试卷主键
     * @return 结果
     */
    @Override
    public int deleteBusExamUserById(Long id)
    {
        return busExamUserMapper.deleteBusExamUserById(id);
    }
}
